package
module
Version:
v0.0.0-...-098f707
Opens a new window with list of versions in this module.
Published: Feb 14, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type AuthLog struct {
LogID string `json:"log_id"`
Host string `json:"host"`
Username string `json:"username"`
Status string `json:"status"`
Timestamp int64 `json:"ts"`
Raw string `json:"raw"`
MachineID string `json:"machine_id"`
}
AuthLog auth log model
Source Files
¶
Click to show internal directories.
Click to hide internal directories.